Impedance package
=================

e\_impedance.e\_impedance
--------------------------

.. automodule:: e_impedance.e_impedance
   :members:
   :undoc-members:
   :show-inheritance:

e\_impedance.e\_impedance\_plotting
------------------------------------

.. automodule:: e_impedance.e_impedance_plotting
   :members:
   :undoc-members:
   :show-inheritance:
